#ifndef APPLICATION_H
#define APPLICATION_H

#include "Document.h"

#include <qmainwindow.h>
#include <qaction.h>
#include <qtoolbar.h>
#include <qpopupmenu.h>
#include <qworkspace.h>
#include <qlist.h>

class ApplicationWindow: public QMainWindow
{
    Q_OBJECT

public:
	enum { FileNewId, FileCloseId, FileQuitId, ViewToolId, ViewStatusId, HelpAboutId };
    enum { ToolWireframeId, ToolShadingId, ToolColorId, ToolMaterialId, ToolTransparencyId, ToolDeleteId };

    ApplicationWindow();
    ~ApplicationWindow();

	static QWorkspace*              getWorkspace();
	static ApplicationWindow*       getApplication();
	static QString                  getResourceDir();

	void                            updateFileActions();
    QList<QAction>*                 getToolActions();
    QList<QAction>*                 getMaterialActions();
	

public slots:
	
    Document*                       onNewDoc();
    void                            onCloseWindow();
	void                            onCloseDocument( Document* theDoc );
	void                            onViewToolBar();
	void                            onViewStatusBar();
	void                            onAbout();
    void                            onToolAction();
    void                            onSelectionChanged();
	void                            onCreateNewView();
    void                            onWindowActivated ( QWidget * w );
	void                            windowsMenuAboutToShow();
    void                            windowsMenuActivated( int id );
	void							onMakeBottleAction();
	void							onSetMaterial( int theMaterial );

protected:
    virtual void                    resizeEvent( QResizeEvent* );

private:
	void                            createStandardOperations();
	void                            createCasCadeOperations();
	void                            createMakeBottleOperation();
	void                            createWindowPopup();

private:
    int                             myNbDocuments;
	bool                            myIsDocuments;

	QList<QAction>                  myStdActions;
    QList<QAction>                  myToolActions;
    QList<QAction>                  myMaterialActions;
    QList<Document>                 myDocuments;

	QToolBar*                       myStdToolBar;
	QToolBar*                       myCasCadeBar;
	QToolBar*						myMakeBottleBar;
	QPopupMenu*                     myFilePopup;
	QPopupMenu*                     myWindowPopup;
};

#endif
